=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-02-22 07:59:56 +0000
+++ bzrlib/builtins.py	2006-02-22 23:54:32 +0000
@@ -125,9 +125,9 @@
     def run(self, all=False, show_ids=False, file_list=None, revision=None):
         tree, file_list = tree_files(file_list)
             
-        from bzrlib.status import show_status
-        show_status(tree.branch, show_unchanged=all, show_ids=show_ids,
-                    specific_files=file_list, revision=revision)
+        from bzrlib.status import show_tree_status
+        show_tree_status(tree, show_unchanged=all, show_ids=show_ids,
+                         specific_files=file_list, revision=revision)
 
 
 class cmd_cat_revision(Command):
@@ -1367,7 +1367,6 @@
                 StrictCommitFailed)
         from bzrlib.msgeditor import edit_commit_message, \
                 make_commit_message_template
-        from bzrlib.status import show_status
         from tempfile import TemporaryFile
         import codecs
 

=== modified file 'bzrlib/msgeditor.py'
--- bzrlib/msgeditor.py	2006-01-25 18:48:21 +0000
+++ bzrlib/msgeditor.py	2006-02-22 23:54:32 +0000
@@ -148,7 +148,8 @@
     # the revision to be committed, then pause and ask the user to
     # confirm/write a message.
     from StringIO import StringIO       # must be unicode-safe
-    from bzrlib.status import show_status
+    from bzrlib.status import show_tree_status
     status_tmp = StringIO()
-    show_status(working_tree.branch, specific_files=specific_files, to_file=status_tmp)
+    show_tree_status(working_tree, specific_files=specific_files, 
+                     to_file=status_tmp)
     return status_tmp.getvalue()

=== modified file 'bzrlib/status.py'
--- bzrlib/status.py	2006-02-14 06:52:21 +0000
+++ bzrlib/status.py	2006-02-22 23:54:32 +0000
@@ -20,11 +20,13 @@
 from bzrlib.errors import NoSuchRevision
 from bzrlib.log import line_log
 from bzrlib.osutils import is_inside_any
+from bzrlib.symbol_versioning import *
 
 # TODO: when showing single-line logs, truncate to the width of the terminal
 # if known, but only if really going to the terminal (not into a file)
 
 
+@deprecated_function(zero_eight)
 def show_status(branch, show_unchanged=False,
                 specific_files=None,
                 show_ids=False,
@@ -60,30 +62,68 @@
         If one revision show compared it with working tree.
         If two revisions show status between first and second.
     """
+    show_tree_status(branch.bzrdir.open_workingtree(), show_unchanged, 
+                     specific_files, show_ids, to_file, show_pending, revision)
+
+def show_tree_status(wt, show_unchanged=False,
+                     specific_files=None,
+                     show_ids=False,
+                     to_file=None,
+                     show_pending=True,
+                     revision=None):
+    """Display summary of changes.
+
+    By default this compares the working tree to a previous revision. 
+    If the revision argument is given, summarizes changes between the 
+    working tree and another, or between two revisions.
+
+    The result is written out as Unicode and to_file should be able 
+    to encode that.
+
+    show_unchanged
+        If set, includes unchanged files.
+
+    specific_files
+        If set, only show the status of files in this list.
+
+    show_ids
+        If set, includes each file's id.
+
+    to_file
+        If set, write to this file (default stdout.)
+
+    show_pending
+        If set, write pending merges.
+
+    revision
+        If None the compare latest revision with working tree
+        If one revision show compared it with working tree.
+        If two revisions show status between first and second.
+    """
     if to_file == None:
         to_file = sys.stdout
     
-    branch.lock_read()
+    wt.lock_read()
     try:
         new_is_working_tree = True
         if revision is None:
-            new = branch.bzrdir.open_workingtree()
+            new = wt
             old = new.basis_tree()
         elif len(revision) > 0:
             try:
-                rev_id = revision[0].in_history(branch).rev_id
-                old = branch.repository.revision_tree(rev_id)
+                rev_id = revision[0].in_history(wt.branch).rev_id
+                old = wt.branch.repository.revision_tree(rev_id)
             except NoSuchRevision, e:
                 raise BzrCommandError(str(e))
             if (len(revision) > 1) and (revision[1].spec is not None):
                 try:
-                    rev_id = revision[1].in_history(branch).rev_id
-                    new = branch.repository.revision_tree(rev_id)
+                    rev_id = revision[1].in_history(wt.branch).rev_id
+                    new = wt.branch.repository.revision_tree(rev_id)
                     new_is_working_tree = False
                 except NoSuchRevision, e:
                     raise BzrCommandError(str(e))
             else:
-                new = branch.bzrdir.open_workingtree()
+                new = wt
                 
         delta = compare_trees(old, new, want_unchanged=show_unchanged,
                               specific_files=specific_files)
@@ -97,7 +137,7 @@
         if new_is_working_tree and show_pending:
             show_pending_merges(new, to_file)
     finally:
-        branch.unlock()
+        wt.unlock()
 
 def show_pending_merges(new, to_file):
     """Write out a display of pending merges in a working tree."""

=== modified file 'bzrlib/tests/blackbox/test_status.py'
--- bzrlib/tests/blackbox/test_status.py	2006-02-14 17:19:40 +0000
+++ bzrlib/tests/blackbox/test_status.py	2006-02-22 23:54:32 +0000
@@ -25,13 +25,16 @@
 
 
 from cStringIO import StringIO
-from os import mkdir
+from os import mkdir, chdir
 from tempfile import TemporaryFile
 import codecs
 
+import bzrlib.branch
 from bzrlib.builtins import merge
+import bzrlib.bzrdir as bzrdir
+from bzrlib.osutils import pathjoin
 from bzrlib.revisionspec import RevisionSpec
-from bzrlib.status import show_status
+from bzrlib.status import show_tree_status
 from bzrlib.tests import TestCaseWithTransport
 from bzrlib.workingtree import WorkingTree
 
@@ -45,13 +48,13 @@
 
         # status with nothing
         tof = StringIO()
-        show_status(b, to_file=tof)
+        show_tree_status(wt, to_file=tof)
         self.assertEquals(tof.getvalue(), "")
 
         tof = StringIO()
         self.build_tree(['hello.c', 'bye.c'])
         wt.add_pending_merge('pending@pending-0-0')
-        show_status(b, to_file=tof)
+        show_tree_status(wt, to_file=tof)
         tof.seek(0)
         self.assertEquals(tof.readlines(),
                           ['unknown:\n',
@@ -76,7 +79,7 @@
         revs =[]
         revs.append(RevisionSpec(0))
         
-        show_status(b, to_file=tof, revision=revs)
+        show_tree_status(wt, to_file=tof, revision=revs)
         
         tof.seek(0)
         self.assertEquals(tof.readlines(),
@@ -90,8 +93,11 @@
         
         tof = StringIO()
         revs.append(RevisionSpec(1))
-        
-        show_status(b, to_file=tof, revision=revs)
+      
+
+
+
+        show_tree_status(wt, to_file=tof, revision=revs)
         
         tof.seek(0)
         self.assertEquals(tof.readlines(),
@@ -99,11 +105,11 @@
                            '  bye.c\n',
                            '  hello.c\n'])
 
-    def status_string(self, branch):
+    def status_string(self, wt):
         # use a real file rather than StringIO because it doesn't handle
         # Unicode very well.
         tof = codecs.getwriter('utf-8')(TemporaryFile())
-        show_status(branch, to_file=tof)
+        show_tree_status(wt, to_file=tof)
         tof.seek(0)
         return tof.read().decode('utf-8')
 
@@ -118,7 +124,7 @@
         wt2 = b_2_dir.open_workingtree()
         wt.commit(u"\N{TIBETAN DIGIT TWO} Empty commit 2")
         merge(["./branch", -1], [None, None], this_dir = './copy')
-        message = self.status_string(b_2)
+        message = self.status_string(wt2)
         self.assert_(message.startswith("pending merges:\n"))
         self.assert_(message.endswith("Empty commit 2\n")) 
         wt2.commit("merged")
@@ -126,7 +132,7 @@
         wt.commit("Empty commit 3 " + 
                    "blah blah blah blah " * 10)
         merge(["./branch", -1], [None, None], this_dir = './copy')
-        message = self.status_string(b_2)
+        message = self.status_string(wt2)
         self.assert_(message.startswith("pending merges:\n"))
         self.assert_("Empty commit 3" in message)
         self.assert_(message.endswith("...\n")) 
@@ -142,7 +148,7 @@
         wt.commit('testing')
         
         tof = StringIO()
-        show_status(b, to_file=tof)
+        show_tree_status(wt, to_file=tof)
         tof.seek(0)
         self.assertEquals(tof.readlines(),
                           ['unknown:\n',
@@ -152,7 +158,7 @@
                            ])
 
         tof = StringIO()
-        show_status(b, specific_files=['bye.c','test.c','absent.c'], to_file=tof)
+        show_tree_status(wt, specific_files=['bye.c','test.c','absent.c'], to_file=tof)
         tof.seek(0)
         self.assertEquals(tof.readlines(),
                           ['unknown:\n',
@@ -160,20 +166,32 @@
                            ])
         
         tof = StringIO()
-        show_status(b, specific_files=['directory'], to_file=tof)
+        show_tree_status(wt, specific_files=['directory'], to_file=tof)
         tof.seek(0)
         self.assertEquals(tof.readlines(),
                           ['unknown:\n',
                            '  directory/hello.c\n'
                            ])
         tof = StringIO()
-        show_status(b, specific_files=['dir2'], to_file=tof)
+        show_tree_status(wt, specific_files=['dir2'], to_file=tof)
         tof.seek(0)
         self.assertEquals(tof.readlines(),
                           ['unknown:\n',
                            '  dir2\n'
                            ])
 
+class CheckoutStatus(BranchStatus):
+    def setUp(self):
+        super(CheckoutStatus, self).setUp()
+        mkdir('codir')
+        chdir('codir')
+        
+    def make_branch_and_tree(self, relpath):
+        source = self.make_branch(pathjoin('..', relpath))
+        checkout = bzrdir.BzrDirMetaFormat1().initialize(relpath)
+        bzrlib.branch.BranchReferenceFormat().initialize(checkout, source)
+        return checkout.create_workingtree()
+
 
 class TestStatus(TestCaseWithTransport):
 

=== modified file 'bzrlib/tests/test_bad_files.py'
--- bzrlib/tests/test_bad_files.py	2006-01-24 04:44:33 +0000
+++ bzrlib/tests/test_bad_files.py	2006-02-22 23:54:32 +0000
@@ -22,12 +22,12 @@
 from bzrlib.errors import BadFileKindError
 import os
 
-def verify_status(tester, branch, value):
-    from bzrlib.status import show_status
+def verify_status(tester, tree, value):
+    from bzrlib.status import show_tree_status
     from cStringIO import StringIO
 
     tof = StringIO()
-    show_status(branch, to_file=tof)
+    show_tree_status(tree, to_file=tof)
     tof.seek(0)
     tester.assertEquals(tof.readlines(), value)
 
@@ -61,12 +61,12 @@
             return
 
         # status with nothing
-        verify_status(self, b, [])
+        verify_status(self, wt, [])
 
         os.mkfifo('a-fifo')
         self.build_tree(['six'])
 
-        verify_status(self, b,
+        verify_status(self, wt,
                           ['unknown:\n',
                            '  a-fifo\n',
                            '  six\n'
@@ -75,7 +75,7 @@
         # Make sure smart_add can handle having a bogus
         # file in the way
         smart_add_tree(wt, '.')
-        verify_status(self, b,
+        verify_status(self, wt,
                           ['added:\n',
                            '  six\n',
                            'unknown:\n',
@@ -83,7 +83,7 @@
                            ])
         wt.commit("Commit four", rev_id="a@u-0-3")
 
-        verify_status(self, b,
+        verify_status(self, wt,
                           ['unknown:\n',
                            '  a-fifo\n',
                            ])

